/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.msq.indexing;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.Preconditions;

import java.util.Objects;

public class ColumnMapping
{
  private final String queryColumn;
  private final String outputColumn;

  @JsonCreator
  public ColumnMapping(
      @JsonProperty("queryColumn") String queryColumn,
      @JsonProperty("outputColumn") String outputColumn
  )
  {
    this.queryColumn = Preconditions.checkNotNull(queryColumn, "queryColumn");
    this.outputColumn = Preconditions.checkNotNull(outputColumn, "outputColumn");
  }

  @JsonProperty
  public String getQueryColumn()
  {
    return queryColumn;
  }

  @JsonProperty
  public String getOutputColumn()
  {
    return outputColumn;
  }

  @Override
  public boolean equals(Object o)
  {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    ColumnMapping that = (ColumnMapping) o;
    return Objects.equals(queryColumn, that.queryColumn) && Objects.equals(outputColumn, that.outputColumn);
  }

  @Override
  public int hashCode()
  {
    return Objects.hash(queryColumn, outputColumn);
  }

  @Override
  public String toString()
  {
    return "ColumnMapping{" +
           "queryColumn='" + queryColumn + '\'' +
           ", outputColumn='" + outputColumn + '\'' +
           '}';
  }
}
