/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.segment.incremental;

import java.util.Collections;
import java.util.Map;

/**
 * This class is used only in {@code RealtimeIndexTask} which is deprecated now.
 *
 * Consider using {@link RowIngestionMetersFactory} instead.
 */
public class NoopRowIngestionMeters implements RowIngestionMeters
{
  private static final RowIngestionMetersTotals EMPTY_TOTALS = new RowIngestionMetersTotals(0, 0, 0, 0);

  @Override
  public long getProcessed()
  {
    return 0;
  }

  @Override
  public void incrementProcessed()
  {

  }

  @Override
  public long getProcessedWithError()
  {
    return 0;
  }

  @Override
  public void incrementProcessedWithError()
  {

  }

  @Override
  public long getUnparseable()
  {
    return 0;
  }

  @Override
  public void incrementUnparseable()
  {

  }

  @Override
  public long getThrownAway()
  {
    return 0;
  }

  @Override
  public void incrementThrownAway()
  {

  }

  @Override
  public RowIngestionMetersTotals getTotals()
  {
    return EMPTY_TOTALS;
  }

  @Override
  public Map<String, Object> getMovingAverages()
  {
    return Collections.emptyMap();
  }
}
