/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { IconNames } from '@blueprintjs/icons';
import React from 'react';

import { LocalStorageKeys } from '../../utils';
import { DelayLabel, TimedButton } from '../timed-button/timed-button';

const DELAYS: DelayLabel[] = [
  { label: '5 seconds', delay: 5000 },
  { label: '10 seconds', delay: 10000 },
  { label: '30 seconds', delay: 30000 },
  { label: '1 minute', delay: 60000 },
  { label: '2 minutes', delay: 120000 },
  { label: 'None', delay: 0 },
];

export interface RefreshButtonProps {
  onRefresh: (auto: boolean) => void;
  localStorageKey?: LocalStorageKeys;
}

export const RefreshButton = React.memo(function RefreshButton(props: RefreshButtonProps) {
  const { onRefresh, localStorageKey } = props;

  return (
    <TimedButton
      className="refresh-button"
      defaultDelay={30000}
      label="Auto refresh every"
      delays={DELAYS}
      icon={IconNames.REFRESH}
      text="Refresh"
      onRefresh={onRefresh}
      foregroundOnly
      localStorageKey={localStorageKey}
    />
  );
});
